const module
============

A series of physical constants and constants relevant to running the APEC code.

.. automodule:: pyatomdb.const
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
